/*
 * Copyright (c) 1994 Regents of the University of Michigan.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms are permitted
 * provided that this notice is preserved and that due credit is given
 * to the University of Michigan at Ann Arbor. The name of the University
 * may not be used to endorse or promote products derived from this
 * software without specific prior written permission. This software
 * is provided ``as is'' without express or implied warranty.
 */

/* Tcl_LdapDeleteCmd - simple function to delete an entry using LDAP */

#include <stdio.h>
#include <string.h>
#include <stdlib.h>
#include <ctype.h>
#include "/opt/work/ldap/ldap-3.2/include/lber.h"
#include "/opt/work/ldap/ldap-3.2/include/ldap.h"
#include "/opt/work/ldap/ldap-3.2/include/ldapconfig.h"
#include "tcl.h"
#include "tclInt.h"
#include "tclPort.h"

Tcl_LdapDeleteCmd(dummy, interp, argc, argv)
ClientData dummy;Tcl_Interp *interp;int argc;char **argv;
{
LDAP *ld; char *ldaphost, *dn, *binddn, *passwd; int ldapport = 389; int rc;

if (argc < 5) {
   Tcl_AppendResult(interp, "Too few arguments! Usage: ", (char *) NULL);
   Tcl_AppendResult(interp, argv[0], " Host BindDN Password ", (char *) NULL);
   Tcl_AppendResult(interp, "DN-to-delete", (char *) NULL);
   return TCL_ERROR;
}

ldaphost = argv[1]; binddn = argv[2]; passwd = argv[3]; dn = argv[4];

 if ((ld = ldap_init(ldaphost, ldapport)) == NULL) {
   Tcl_AppendResult(interp, "Cannot connect to host!", (char *) NULL);
   return TCL_ERROR;
 }

 if ((ld = ldap_open(ldaphost, ldapport)) == NULL) {
   Tcl_AppendResult(interp, "Cannot connect to host!", (char *) NULL);
   return TCL_ERROR;
 }

 ld->ld_deref = LDAP_DEREF_NEVER;  /* Turn off alias dereferencing */

  if (ldap_bind_s(ld, binddn, passwd, LDAP_AUTH_SIMPLE) != LDAP_SUCCESS) {
    Tcl_AppendResult(interp, "Invalid name or password!", (char *) NULL);
    return TCL_ERROR;
  }

 if ((rc = ldap_delete_s(ld, dn)) != LDAP_SUCCESS) {
   Tcl_AppendResult(interp, "Unable to delete entry!", (char *) NULL);
   ldap_unbind(ld);
   return TCL_ERROR;
 } else {
   Tcl_AppendResult(interp, "Entry deleted!", (char *) NULL);
   return TCL_OK;
 }

 ldap_unbind(ld);
}
